<!-- markdownlint-disable MD013 -->
<p align="center">
  <a href="https://flame-engine.org">
    <img alt="flame" width="200px" src="https://user-images.githubusercontent.com/6718144/101553774-3bc7b000-39ad-11eb-8a6a-de2daa31bd64.png">
  </a>
</p>

<p align="center">
A flame plugin to import sprite sheets generated by [Gdx Texture Packer][2] and
[Code and Web Texture Packer][1]
</p>

<p align="center">
  <a title="Pub" href="https://pub.dev/packages/flame_texturepacker" ><img src="https://img.shields.io/pub/v/flame_texturepacker.svg?style=popout" /></a>
  <a title="Test" href="https://github.com/flame-engine/flame/actions?query=workflow%3Acicd+branch%3Amain"><img src="https://github.com/flame-engine/flame/workflows/cicd/badge.svg?branch=main&event=push"/></a>
  <a title="Discord" href="https://discord.gg/pxrBmy4"><img src="https://img.shields.io/discord/509714518008528896.svg"/></a>
  <a title="Melos" href="https://github.com/invertase/melos"><img src="https://img.shields.io/badge/maintained%20with-melos-f700ff.svg"/></a>
</p>

---
<!-- markdownlint-enable MD013 -->

<!-- markdownlint-disable-next-line MD002 -->
# flame_texturepacker

TexturePacker is a tool to create efficient sprite sheets. This plugin allows you to import sprite
sheets generated by TexturePacker into your Flame game.

Note: Rotated sprites are not currently supported.


## Install from Pub

```console
flutter pub add flame_texturepacker
```


## Usage


### Asset Storage

Drop generated atlas file and sprite sheet images into the `assets/` and link the files in your
`pubspec.yaml` file:

```yaml
 assets:
    - assets/atlas_map.atlas
    - assets/sprite_sheet1.png
```

Import the plugin like this:

`import 'package:flame_texturepacker/flame_texturepacker.dart';`

Load the TextureAtlas passing the path of the sprite sheet atlas file:

```Dart
final atlas = await fromAtlas('atlas_map.atlas');
```


### File Storage

If you are using file storage, grab your atlas file like this:

```Dart
final documentsPath = (await getApplicationDocumentsDirectory()).path;
final atlas = await fromAtlas('$documentsPath/atlas_map.atlas', fromStorage: true);
```

Get a list of sprites ordered by their index, you can use the list to generate an animation:

```Dart
final spriteList = atlas.findSpritesByName('robot_walk');

final animation = SpriteAnimation.spriteList(
 spriteList,
 stepTime: 0.1,
 loop: true,
);
```

Get individual sprites by name:

```Dart
final jumpSprite = atlas.findSpriteByName('robot_jump')!;
final fallSprite = atlas.findSpriteByName('robot_fall')!;
final idleSprite = atlas.findSpriteByName('robot_idle')!;
```

Full working example can be found in [example folder][3].

Note: Sprites used in this example can be found OpenGameArt [here][4].


## Credits

Thanks to [Jonas Fröber][5] for the original implementation.
Thanks to [Gnarhard][6] for the feature to build the atlas file from a device's storage.

[1]: https://www.codeandweb.com/texturepacker 'Code & Web Texture Packer'
[2]: https://github.com/crashinvaders/gdx-texture-packer-gui 'Gdx Texture Packer'
[3]: example/lib/main.dart 'Full working example'
[4]: https://opengameart.org/content/toon-characters-1 'Robot sprite'
[5]: https://github.com/Brixto
[6]: https://github.com/gnarhard

